@@ -1,4 +1,9 @@
-"""Tests to verify the command line interface."""
+"""Tests to verify the command line interface.
+
+.. spelling::
+
+   cli
+"""
 # -*- coding: utf-8 -*-
 # vim: set fileencoding=utf-8 :
 import sys
@@ -34,7 +39,7 @@ from cheroot.cli import (
 def test_parse_wsgi_bind_addr(raw_bind_addr, expected_bind_addr):
     """Check the parsing of the --bind option.
 
-    Verify some of the supported addresses and the excpected return value.
+    Verify some of the supported addresses and the expected return value.
     """
     assert parse_wsgi_bind_addr(raw_bind_addr) == expected_bind_addr
 
@@ -77,16 +82,17 @@ def wsgi_app(monkeypatch):
 @pytest.mark.parametrize(
     ('app_name', 'app_method'),
     (
-        (None, 'application',),
-        ('application', 'application',),
-        ('main', 'main',),
+        (None, 'application'),
+        ('application', 'application'),
+        ('main', 'main'),
     ),
 )
+# pylint: disable=invalid-name
 def test_Aplication_resolve(app_name, app_method, wsgi_app):
     """Check the wsgi application name conversion."""
     if app_name is None:
         wsgi_app_spec = 'mypkg.wsgi'
     else:
-        wsgi_app_spec = 'mypkg.wsgi:{}'.format(app_name)
+        wsgi_app_spec = 'mypkg.wsgi:{app_name}'.format(**locals())
     expected_app = getattr(wsgi_app, app_method)
     assert Application.resolve(wsgi_app_spec).wsgi_app == expected_app
